package com.ynet.life.sujrb.file.parser;

import com.ynet.gene.core.Context;
import com.ynet.life.base.Trace;
import com.ynet.life.exception.TranFailException;
import com.ynet.life.sujrb.file.BatchCorBaseInfoDetailSummary;
import com.ynet.life.sujrb.file.BatchFileSummary;
import com.ynet.life.sujrb.file.FileConstants;
import java.io.FileInputStream;
import java.io.IOException;
import java.text.DecimalFormat;
import java.text.SimpleDateFormat;
import java.util.HashMap;
import java.util.Map;
import java.util.StringTokenizer;
import java.util.regex.Pattern;
import org.apache.poi.hssf.usermodel.HSSFCell;
import org.apache.poi.hssf.usermodel.HSSFDateUtil;
import org.apache.poi.hssf.usermodel.HSSFRow;
import org.apache.poi.hssf.usermodel.HSSFSheet;
import org.apache.poi.hssf.usermodel.HSSFWorkbook;
import org.apache.poi.poifs.filesystem.OfficeXmlFileException;
import org.apache.poi.poifs.filesystem.POIFSFileSystem;

/* loaded from: com_ynet_life_sujrb_file_parser.jar:com/ynet/life/sujrb/file/parser/BatchCompanyBaseInfoDetail.class */
public class BatchCompanyBaseInfoDetail implements BatchFileParserInterface {
    private String formatter;
    private Context context;

    public BatchCompanyBaseInfoDetail() {
    }

    public BatchCompanyBaseInfoDetail(String formatter) {
        this.formatter = formatter;
    }

    public Context getContext() {
        return this.context;
    }

    public void setContext(Context context) {
        this.context = context;
    }

    @Override // com.ynet.life.sujrb.file.parser.BatchFileParserInterface
    public BatchFileSummary parseFromFile(String filePathName) throws TranFailException {
        try {
            POIFSFileSystem file = new POIFSFileSystem(new FileInputStream(filePathName));
            HSSFWorkbook workBook = new HSSFWorkbook(file);
            BatchCorBaseInfoDetailSummary result = new BatchCorBaseInfoDetailSummary();
            try {
                HSSFSheet sheet = workBook.getSheetAt(0);
                sheet.getRow(0);
                int rowIndex = 1;
                HSSFRow recordRowTemp = sheet.getRow(1);
                if (getCellContent(recordRowTemp, 0, true).trim().equals("结束")) {
                    throw new TranFailException("excelError", "文件解析失败");
                }
                while (true) {
                    int i = rowIndex;
                    rowIndex++;
                    HSSFRow recordRow = sheet.getRow(i);
                    if (!getCellContent(recordRow, 0, true).trim().equals("结束")) {
                        if (this.formatter == null) {
                            result.addRecord(getRecordMap(recordRow));
                        } else {
                            result.addRecord(getRecordMap(recordRow, this.formatter));
                        }
                    } else {
                        return result;
                    }
                }
            } catch (Exception ex) {
                Trace.logError("LifeFile", "文件解析失败，请检查提交文件是否正确，并确保文件未被损坏", ex);
                throw FileConstants.EXCEPTION_PARSE_FAIL;
            }
        } catch (OfficeXmlFileException e) {
            Trace.logError("LifeFile", "Excel版本过高", e);
            throw new TranFailException("excelError", "Excel版本过高");
        } catch (IOException ex2) {
            Trace.logError("LifeFile", "文件读取失败", ex2);
            throw new TranFailException("excelError", "文件读取失败");
        }
    }

    private Map getRecordMap(HSSFRow recordRow) throws TranFailException {
        Map result = new HashMap();
        String orgCode = getCellContent(recordRow, 0, true);
        String corpCode = getCellContent(recordRow, 1, true);
        String corName = getCellContent(recordRow, 2, true);
        String belongFunc = getCellContent(recordRow, 3, true);
        String newProduceType = getCellContent(recordRow, 4, true);
        String onMarket = getCellContent(recordRow, 5, true);
        String marketType = getCellContent(recordRow, 6, true);
        String corContactName = getCellContent(recordRow, 7, true);
        String corContactTel = getCellContent(recordRow, 8, true);
        String corContactPho = getCellContent(recordRow, 9, true);
        String corEmail = getCellContent(recordRow, 10, true);
        String acountType = getCellContent(recordRow, 11, true);
        String acountFinance = getCellContent(recordRow, 12, true);
        String financeAcountNo = getCellContent(recordRow, 13, true);
        String acountName = getCellContent(recordRow, 14, true);
        String remark = "";
        if (!"".equals(corpCode) && corpCode != null && !Pattern.compile("^[a-zA-Z0-9[-]]{8,25}").matcher(corpCode).matches()) {
            remark = String.valueOf(remark) + "统一社会信用代码不符合规则";
        }
        if ("".equals(corName) || corName == null) {
            remark = String.valueOf(remark) + " 企业名称为空";
        } else {
            String replace = corName.replace("(", "（").replace(")", "）");
            corName = replace;
            if (replace.length() > 50) {
                remark = String.valueOf(remark) + "企业名称过长";
            }
        }
        if (!"".equals(onMarket) && corContactPho != null && !"是".equals(onMarket) && !"否".equals(onMarket)) {
            remark = String.valueOf(remark) + "是否上市不正确";
        }
        result.put("orgCode", orgCode);
        result.put("corpCode", corpCode);
        result.put("corName", corName);
        result.put("belongFunc", belongFunc);
        result.put("newProduceType", newProduceType);
        result.put("onMarket", onMarket);
        result.put("marketType", marketType);
        result.put("corContactName", corContactName);
        result.put("corContactTel", corContactTel);
        result.put("corContactPho", corContactPho);
        result.put("corEmail", corEmail);
        result.put("acountType", acountType);
        result.put("acountFinance", acountFinance);
        result.put("financeAcountNo", financeAcountNo);
        result.put("acountName", acountName);
        result.put("didRemark", remark);
        return result;
    }

    private Map getRecordMap(HSSFRow recordRow, String formatter) throws TranFailException {
        Map result = new HashMap();
        StringTokenizer formatters = new StringTokenizer(formatter, "||");
        int i = 0;
        while (formatters.hasMoreTokens()) {
            String name = (String) formatters.nextElement();
            result.put(name, getCellContent(recordRow, i, true));
            i++;
        }
        return result;
    }

    /* JADX WARN: Can't fix incorrect switch cases order, some code will duplicate */
    private String getCellContent(HSSFRow row, int index, boolean toInt) throws TranFailException {
        String result = null;
        try {
            HSSFCell cell = row.getCell(index);
            if (cell != null) {
                switch (cell.getCellType()) {
                    case 0:
                        String format = "######.##";
                        if (toInt) {
                            format = "#######";
                        }
                        if (HSSFDateUtil.isCellDateFormatted(cell)) {
                            result = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss").format(HSSFDateUtil.getJavaDate(cell.getNumericCellValue()));
                            break;
                        } else {
                            result = new DecimalFormat(format).format(cell.getNumericCellValue());
                            break;
                        }
                    case 1:
                        result = cell.getRichStringCellValue().getString();
                        break;
                }
            }
            return result == null ? "" : result.trim();
        } catch (Exception ex) {
            Trace.logError("LifeFile", "文件解析失败，请检查提交文件是否正确，并确保文件未被损坏", ex);
            throw FileConstants.EXCEPTION_PARSE_FAIL;
        }
    }

    @Override // com.ynet.life.sujrb.file.parser.BatchFileParserInterface
    public void writeToFile(BatchFileSummary salary, String filePathName, String encoding) throws TranFailException {
    }
}
